@@ -13,6 +13,7 @@ from aind_data_transfer.config_loader.imaging_configuration_loader import (
 )
 from aind_data_transfer.readers.imaging_readers import ImagingReaders
 from aind_data_transfer.util.file_utils import is_cloud_url, parse_cloud_url
+from aind_data_transfer.writers.imaging_writers import ExASPIMWriter
 
 LOGGER = logging.getLogger(__name__)
 LOGGER.setLevel(logging.INFO)
@@ -151,8 +152,9 @@ def main():
         # remove trailing slash
         dest_data_dir = dest_data_dir[:-1]
 
+    reader = ImagingReaders.get_reader_name(data_src_dir)
     raw_image_dir = ImagingReaders.get_raw_data_dir(
-        ImagingReaders.get_reader_name(data_src_dir), data_src_dir
+        reader, data_src_dir
     )
 
     LOGGER.info(f"Transferring data to {dest_data_dir}")
@@ -187,6 +189,16 @@ def main():
                 f"Creating neuroglancer link failed; {output_json} was not created"
             )
 
+    if job_configs["jobs"]["create_metadata"]:
+        if reader == ImagingReaders.Readers.exaspim.value:
+            metadata_service_url = job_configs["endpoints"]["metadata_service_url"]
+            writer = ExASPIMWriter(data_src_dir, metadata_service_url)
+            writer.write_subject(data_src_dir)
+            writer.write_data_description(data_src_dir)
+            writer.write_procedures(data_src_dir)
+        else:
+            LOGGER.error(f"Fetching metadata not implemented for {reader}")
+
     if job_configs["jobs"]["upload_aux_files"]:
         LOGGER.info("Uploading auxiliary data")
         t0 = time.time()
